MethodChannelSecurx class

An implementation of SecurxPlatform that uses method channels.

Inheritance

Constructors

MethodChannelSecurx()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

disableScreenshot() → Future<void>
override
enableScreenshot() → Future<void>
override
getPlatformVersion() → Future<String?>
override
isAppCloned({required String applicationID}) → Future<bool?>
override
isDebuggerAttached() → Future<bool?>
override
isDebuggingModeEnable() → Future<bool?>
override
isDeveloperModeEnabled() → Future<bool?>
override
isDeviceRooted() → Future<bool?>
override
isDeviceSafe() → Future<bool?>
override
isEmulator() → Future<bool?>
override
isVpnEnabled() → Future<bool?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited